!*************************************************************************************************
! Start up procedures for selected sites
! (read common parameters and climate data)
!*************************************************************************************************
   Include 'modules.f90'        
   Include 'main.f90'           
   Include 'initialize.f90'     
   Include 'metabolic.f90'      
   Include 'output.f90'         
   Include 'physics.f90'        
   Include 'population_regu.f90'
   Include 'spacial_calc.f90'   
   Include 'etc.f90'            

PROGRAM start_point

!_____________ Set variables
!Namespace
   USE data_structure
   implicit none
   
!Climate data
   real,dimension(365)::tmp_air   !2m air temperature (Celcius)
   real,dimension(365)::tmp_soil  !soil temperature at 10 cm  depth (Celcius)
   real,dimension(365)::cloud     !total cloudiness (fraction)
   real,dimension(365)::prec      !precipitation (mm day-1)
   real,dimension(365)::humid     !specific humidity (kg kg-1)
   real,dimension(365)::wind      !wind velocity (m s-1)
   
!Location data
   integer Mask         !Land ocean mask (1:land, 0:ocean)
   real    ALT          !altitude (m above MSL)
   real    Albedo_soil0 !albedo, default
   real    W_fi         !filed capacity   (m3/m3, 0.0 -> 1.0)
   real    W_wilt       !wilting point    (m3/m3, 0.0 -> 1.0)
   real    W_sat        !saturate point   (m3/m3, 0.0 -> 1.0)
   real    W_mat        !matrix potential (m, -0.0001 -> -3.0)
   
!Others
   real    LAT, LON   !latitude and logitude for simulate
   integer point, i   !for general usage
   real    a1, a2, a3 !for general usage
   
!_____________ Set location
!  LAT    north:+, south:- (decimalized)
!  LON    east:+, west:-   (decimalized)
   !Deramakot
    LAT    = 5.42  
    LON    = 117.50 

!set cordinate variables
   point = (90-int(LAT)-1)*360 + int(LON+180) + 1

!_____________ Prepare input data
!Read Parameter files
   open (1, file='parameter.txt', action='READ', status='OLD')
      read ( unit=1, nml=Control)       
      read ( unit=1, nml=PFT_type)      
      read ( unit=1, nml=Respiration)   
      read ( unit=1, nml=Turnover_n)    
      read ( unit=1, nml=Metabolic)     
      read ( unit=1, nml=Assimilation)  
      read ( unit=1, nml=Dynamics)      
      read ( unit=1, nml=Disturbance)   
      read ( unit=1, nml=Soil_resp)     
      read ( unit=1, nml=Soil_hydrology)
   close (1)
   
!Location data
   write (*,*) 'reading location data...'
   
   !mask
   open ( File_no(1), file=Fn_location(1), status='OLD')
   do i=1, point; read(File_no(1),*) Mask; end do
   close( File_no(1) )
   
   !altitude
   open ( File_no(1), file=Fn_location(2), status='OLD')
   do i=1, point; read(File_no(1),*) ALT; end do
   close( File_no(1) )
   
   !albedo of soil
   open ( File_no(1), file=Fn_location(3), status='OLD')
   do i=1, point; read(File_no(1),*) Albedo_soil0; end do
   close( File_no(1) )
   
   !field capacity
   open ( File_no(1), file=Fn_location(4), status='OLD')
   do i=1, point; read(File_no(1),*) W_fi; end do
   close( File_no(1) )
   
   !saturate point
   open ( File_no(1), file=Fn_location(5), status='OLD')
   do i=1, point; read(File_no(1),*) W_sat; end do
   close( File_no(1) )
   
   !matrix potential
   open ( File_no(1), file=Fn_location(6), status='OLD')
   do i=1, point; read(File_no(1),*) W_mat; end do
   close( File_no(1) )
   W_mat = -1.00*W_mat
   
   !wilting point
   open ( File_no(1), file=Fn_location(7), status='OLD')
   do i=1, point; read(File_no(1),*) W_wilt; end do
   close( File_no(1) )
   
   !data processing
   if (W_fi   > W_sat ) W_fi   = W_sat
   if (W_mat  > W_sat ) W_mat  = W_sat
   if (W_wilt > W_sat ) W_wilt = W_sat
   
   !checker
   if ( Mask         == 0  .or. &
       ALT          <= 0.0 .or. &
       Albedo_soil0 <= 0.0 .or. &
       W_sat        <= 0.0 .or. &
       W_fi         <= 0.0 .or. &
       W_mat        <= 0.0 .or. &
       W_wilt       <= 0.0        ) STOP
   
!Climatic data
    write (*,*) 'reading climate data...'
    
    open ( File_no(1), file=Fn_climate, status='OLD')
    do i=1, 365
       read (File_no(1),*) tmp_air(i), tmp_soil(i), prec(i), cloud(i), wind(i), humid(i)
    enddo
    close (File_no(1))

!_____________ Simulation
   
   !Print location properties
   write (*,*)
   write (*,*) '*********  Coodinate Configurations  *********'
   write (*,*) 'Latitude, Longtitude   :', LAT, LON
   write (*,*) 'Point nomal            :', point
   write (*,*)
   
   !Print soil properties
   write (*,*) '*********  Location properties  *********'
   write (*,*) 'Altitude    :', ALT         
   write (*,*) 'Albedo_soil0:', Albedo_soil0
   write (*,*) 'W_sat       :', W_sat       
   write (*,*) 'W_fi        :', W_fi        
   write (*,*) 'W_mat       :', W_mat       
   write (*,*) 'W_wilt      :', W_wilt      
   write (*,*)                              
   
   !Print climate properties
   write (*,*) '*********  Wether statistics (annual mean)  *********'
   write (*,*) '2m air temperature  (Cecius)  :', sum(tmp_air (:)) / 365.0
   write (*,*) 'soil temperature    (Cecius)  :', sum(tmp_soil(:)) / 365.0
   write (*,*) 'precipitation       (mm/year) :', sum(prec    (:))        
   write (*,*) 'cloud               (fraction):', sum(cloud   (:)) / 365.0
   write (*,*) 'humidity            (kg/kg)   :', sum(humid   (:)) / 365.0
   write (*,*) 'wind                (m/s)     :', sum(wind    (:)) / 365.0
   write (*,*) 
  
   !Call simulation loop
   write (*,*) '*********  Now simulating  *********'
   write (*,*) 
   Call main_loop ( &
   LAT, LON, &
   tmp_air(:), tmp_soil(:), cloud(:), prec(:), humid(:), wind(:), &
   ALT, Albedo_soil0, W_fi, W_wilt, W_sat, W_mat )
   
   write (*,*) '*********  Done  *********'
   
   STOP
   
END PROGRAM start_point
